
TODO: TODO_01_47_82_92: keep applying best practices

Project `argrelay` was initially written with focus to get it working to assess its practical value
(with limited attention to the process, except for testing).

This item marks all places which may need non-functional improvements:
*   making things more "pythonic"
*   following some conventions
*   adding linters and code auto-formatters
*   generating reports (e.g. test coverage, static analysis, ...)
*   clarifying packaging and docs
*   ...

Some relevant items which are already spun off:
*   TODO: TODO_04_84_79_11: reorganize tests for CI
*   TODO: TODO_78_94_31_68: split argrelay into multiple packages
